@@ -1,5 +1,9 @@
 var NAVTREEINDEX55 =
 {
+"group__block.html":[4,0],
+"group__boolean__operators__blk.html":[4,0,2],
+"group__byte__operators__blk.html":[4,0,3],
+"group__channel__models__blk.html":[4,0,4],
 "group__channelizers__blk.html":[4,0,5],
 "group__coding__blk.html":[4,0,6],
 "group__container__blk.html":[4,0,0],
@@ -245,9 +249,5 @@ var NAVTREEINDEX55 =
 "high__res__timer__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,3,1,0,0,0,0,14,0],
 "high__res__timer__pydoc__template_8h.html#ab80fbe78f3321e9b0f8e59e34c9c2bbe":[7,0,3,1,0,0,0,0,14,3],
 "high__res__timer__pydoc__template_8h.html#ad3c800585f3cab699e653eabeee9d991":[7,0,3,1,0,0,0,0,14,2],
-"high__res__timer__pydoc__template_8h.html#ad5f7ab477e3c390a4019bbb777b83a82":[7,0,3,1,0,0,0,0,14,1],
-"high__res__timer__pydoc__template_8h_source.html":[7,0,3,1,0,0,0,0,14],
-"hilbert__fc_8h.html":[7,0,21,1,0,0,15],
-"hilbert__fc_8h_source.html":[7,0,21,1,0,0,15],
-"hilbert__fc__pydoc__template_8h.html":[7,0,21,2,0,0,0,14]
+"high__res__timer__pydoc__template_8h.html#ad5f7ab477e3c390a4019bbb777b83a82":[7,0,3,1,0,0,0,0,14,1]
 };
