@@ -1,5 +1,10 @@
 var NAVTREEINDEX58 =
 {
+"maxstar_8h.html#a07ef3fc3f5370c001c90157ab2a48390":[7,0,17,1,0,0,31,9],
+"maxstar_8h.html#a137ede40502196153ffd48ed1fa8b3b1":[7,0,17,1,0,0,31,22],
+"maxstar_8h.html#a2881716c80d008b61125d314ecfa91f6":[7,0,17,1,0,0,31,5],
+"maxstar_8h.html#a2900d511872eae2e209d6a7000819871":[7,0,17,1,0,0,31,10],
+"maxstar_8h.html#a2bd1b32bd380bd538d7f305dca11ffb2":[7,0,17,1,0,0,31,12],
 "maxstar_8h.html#a2c320230820ada5cf49c1932925ac6fc":[7,0,17,1,0,0,31,15],
 "maxstar_8h.html#a304ec843dc9813e633fb2a8affc56139":[7,0,17,1,0,0,31,16],
 "maxstar_8h.html#a3e59e986aa98853b41d7b1fee9f37a1e":[7,0,17,1,0,0,31,28],
@@ -244,10 +249,5 @@ var NAVTREEINDEX58 =
 "mpsk__snr__est__pydoc__template_8h.html#af1efab1f2d793ab4b50342c037ced7cc":[7,0,13,2,0,0,0,56,14],
 "mpsk__snr__est__pydoc__template_8h.html#af6679e09d2192854f99d26953378cded":[7,0,13,2,0,0,0,56,20],
 "mpsk__snr__est__pydoc__template_8h.html#af69730f607f5988e586f4ef7e5ef4573":[7,0,13,2,0,0,0,56,7],
-"mpsk__snr__est__pydoc__template_8h.html#af8354a9022ec66cf6ec2b82d49169598":[7,0,13,2,0,0,0,56,34],
-"mpsk__snr__est__pydoc__template_8h_source.html":[7,0,13,2,0,0,0,56],
-"msg__accepter_8h.html":[7,0,3,0,0,31],
-"msg__accepter_8h_source.html":[7,0,3,0,0,31],
-"msg__accepter__msgq_8h.html":[7,0,3,0,0,0,1],
-"msg__accepter__msgq_8h_source.html":[7,0,3,0,0,0,1]
+"mpsk__snr__est__pydoc__template_8h.html#af8354a9022ec66cf6ec2b82d49169598":[7,0,13,2,0,0,0,56,34]
 };
