@@ -1,5 +1,6 @@
 var NAVTREEINDEX71 =
 {
+"regenerate__bb__pydoc__template_8h.html#aaf3414624c4423f950b7c0f745ef0684":[7,0,9,2,0,0,0,102,5],
 "regenerate__bb__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,102],
 "rep__msg__sink_8h.html":[7,0,42,1,0,0,7],
 "rep__msg__sink_8h_source.html":[7,0,42,1,0,0,7],
@@ -248,6 +249,5 @@ var NAVTREEINDEX71 =
 "rfnoc__tx__radio__pydoc__template_8h.html#a9ff7819a64d51679a9f428c7af75c2e9":[7,0,34,2,0,0,0,11,6],
 "rfnoc__tx__radio__pydoc__template_8h.html#aa37a4b60adad5dd4345608c81d580075":[7,0,34,2,0,0,0,11,11],
 "rfnoc__tx__radio__pydoc__template_8h.html#aab17b5a03120497a6dc5061ad4da617e":[7,0,34,2,0,0,0,11,2],
-"rfnoc__tx__radio__pydoc__template_8h.html#ab46c422b9cb366d5615149ca1e2f457f":[7,0,34,2,0,0,0,11,3],
-"rfnoc__tx__radio__pydoc__template_8h.html#ac5c1a8bf4435de092cf9322c6678d8dd":[7,0,34,2,0,0,0,11,12]
+"rfnoc__tx__radio__pydoc__template_8h.html#ab46c422b9cb366d5615149ca1e2f457f":[7,0,34,2,0,0,0,11,3]
 };
